/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtcore_python.h"

#include "qdiriterator_wrapper.h"

// Extra includes
#include <qdir.h>
#include <qdiriterator.h>
#include <qfileinfo.h>
#include <qstring.h>
#include <qstringlist.h>

using namespace Shiboken;

// Native ---------------------------------------------------------

QDirIteratorWrapper::QDirIteratorWrapper(const QDir & dir, QFlags<QDirIterator::IteratorFlag> flags) : QDirIterator(dir, flags) {
    // ... middle
}

QDirIteratorWrapper::QDirIteratorWrapper(const QString & path, QFlags<QDir::Filter> filter, QFlags<QDirIterator::IteratorFlag> flags) : QDirIterator(path, filter, flags) {
    // ... middle
}

QDirIteratorWrapper::QDirIteratorWrapper(const QString & path, QFlags<QDirIterator::IteratorFlag> flags) : QDirIterator(path, flags) {
    // ... middle
}

QDirIteratorWrapper::QDirIteratorWrapper(const QString & path, const QStringList & nameFilters, QFlags<QDir::Filter> filters, QFlags<QDirIterator::IteratorFlag> flags) : QDirIterator(path, nameFilters, filters, flags) {
    // ... middle
}

QDirIteratorWrapper::~QDirIteratorWrapper()
{
    BindingManager::instance().invalidateWrapper(this);
}

// Target ---------------------------------------------------------

static int
SbkQDirIterator_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    QDirIteratorWrapper* cptr = 0;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    if (!PyArg_UnpackTuple(args, "QDirIterator", 1, 4, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return -1;

    if (Shiboken::Converter<QString & >::isConvertible(pyargs[0])) {
        if (Shiboken::cppObjectIsInvalid(pyargs[0]))
            return -1;
        std::auto_ptr<QString > cpp_arg0_auto_ptr;
        QString* cpp_arg0 = Shiboken::Converter<QString* >::toCpp(pyargs[0]);
        if (!SbkQString_Check(pyargs[0]))
            cpp_arg0_auto_ptr = std::auto_ptr<QString >(cpp_arg0);
        if (numArgs == 1) {
            // QDirIterator(QString,QFlags<QDirIterator::IteratorFlag>)
            cptr = new QDirIteratorWrapper(*cpp_arg0);
            //CppGenerator::writeParentChildManagement
        } else if (Shiboken::Converter<QStringList & >::isConvertible(pyargs[1])) {
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return -1;
            std::auto_ptr<QStringList > cpp_arg1_auto_ptr;
            QStringList* cpp_arg1 = Shiboken::Converter<QStringList* >::toCpp(pyargs[1]);
            if (!SbkQStringList_Check(pyargs[1]))
                cpp_arg1_auto_ptr = std::auto_ptr<QStringList >(cpp_arg1);
            if (numArgs == 2) {
                // QDirIterator(QString,QStringList,QFlags<QDir::Filter>,QFlags<QDirIterator::IteratorFlag>)
                cptr = new QDirIteratorWrapper(*cpp_arg0, *cpp_arg1);
                //CppGenerator::writeParentChildManagement
            } else if (SbkPySide_QtCore_QDir_Filter_Check(pyargs[2])) {
                QFlags<QDir::Filter> cpp_arg2 = Shiboken::Converter<QFlags<QDir::Filter> >::toCpp(pyargs[2]);
                if (numArgs == 3) {
                    // QDirIterator(QString,QStringList,QFlags<QDir::Filter>,QFlags<QDirIterator::IteratorFlag>)
                    cptr = new QDirIteratorWrapper(*cpp_arg0, *cpp_arg1, cpp_arg2);
                    //CppGenerator::writeParentChildManagement
                } else if (SbkPySide_QtCore_QDirIterator_IteratorFlag_Check(pyargs[3])) {
                    QFlags<QDirIterator::IteratorFlag> cpp_arg3 = Shiboken::Converter<QFlags<QDirIterator::IteratorFlag> >::toCpp(pyargs[3]);
                    // QDirIterator(QString,QStringList,QFlags<QDir::Filter>,QFlags<QDirIterator::IteratorFlag>)
                    cptr = new QDirIteratorWrapper(*cpp_arg0, *cpp_arg1, cpp_arg2, cpp_arg3);
                    //CppGenerator::writeParentChildManagement
                } else goto SbkQDirIterator_Init_TypeError;
            } else goto SbkQDirIterator_Init_TypeError;
        } else if (SbkPySide_QtCore_QDirIterator_IteratorFlag_Check(pyargs[1])) {
            QFlags<QDirIterator::IteratorFlag> cpp_arg1 = Shiboken::Converter<QFlags<QDirIterator::IteratorFlag> >::toCpp(pyargs[1]);
            // QDirIterator(QString,QFlags<QDirIterator::IteratorFlag>)
            cptr = new QDirIteratorWrapper(*cpp_arg0, cpp_arg1);
            //CppGenerator::writeParentChildManagement
        } else if (SbkPySide_QtCore_QDir_Filter_Check(pyargs[1])) {
            QFlags<QDir::Filter> cpp_arg1 = Shiboken::Converter<QFlags<QDir::Filter> >::toCpp(pyargs[1]);
            if (numArgs == 2) {
                // QDirIterator(QString,QFlags<QDir::Filter>,QFlags<QDirIterator::IteratorFlag>)
                cptr = new QDirIteratorWrapper(*cpp_arg0, cpp_arg1);
                //CppGenerator::writeParentChildManagement
            } else if (SbkPySide_QtCore_QDirIterator_IteratorFlag_Check(pyargs[2])) {
                QFlags<QDirIterator::IteratorFlag> cpp_arg2 = Shiboken::Converter<QFlags<QDirIterator::IteratorFlag> >::toCpp(pyargs[2]);
                // QDirIterator(QString,QFlags<QDir::Filter>,QFlags<QDirIterator::IteratorFlag>)
                cptr = new QDirIteratorWrapper(*cpp_arg0, cpp_arg1, cpp_arg2);
                //CppGenerator::writeParentChildManagement
            } else goto SbkQDirIterator_Init_TypeError;
        } else goto SbkQDirIterator_Init_TypeError;
    } else if (Shiboken::Converter<QDir & >::isConvertible(pyargs[0])) {
        if (Shiboken::cppObjectIsInvalid(pyargs[0]))
            return -1;
        std::auto_ptr<QDir > cpp_arg0_auto_ptr;
        QDir* cpp_arg0 = Shiboken::Converter<QDir* >::toCpp(pyargs[0]);
        if (!SbkQDir_Check(pyargs[0]))
            cpp_arg0_auto_ptr = std::auto_ptr<QDir >(cpp_arg0);
        if (numArgs == 1) {
            // QDirIterator(QDir,QFlags<QDirIterator::IteratorFlag>)
            cptr = new QDirIteratorWrapper(*cpp_arg0);
            //CppGenerator::writeParentChildManagement
        } else if (SbkPySide_QtCore_QDirIterator_IteratorFlag_Check(pyargs[1])) {
            QFlags<QDirIterator::IteratorFlag> cpp_arg1 = Shiboken::Converter<QFlags<QDirIterator::IteratorFlag> >::toCpp(pyargs[1]);
            // QDirIterator(QDir,QFlags<QDirIterator::IteratorFlag>)
            cptr = new QDirIteratorWrapper(*cpp_arg0, cpp_arg1);
            //CppGenerator::writeParentChildManagement
        } else goto SbkQDirIterator_Init_TypeError;
    } else goto SbkQDirIterator_Init_TypeError;

    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QDirIterator >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQDirIterator_Init_TypeError;

    sbkSelf->validCppObject = 1;
    sbkSelf->containsCppWrapper = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);

    return 1;

    SbkQDirIterator_Init_TypeError:
        const char* overloads[] = {"PySide.QtCore.QDir, PySide.QtCore.QDirIterator.IteratorFlags = QDirIterator.NoIteratorFlags", "PySide.QtCore.QString, PySide.QtCore.QDir.Filters, PySide.QtCore.QDirIterator.IteratorFlags = QDirIterator.NoIteratorFlags", "PySide.QtCore.QString, PySide.QtCore.QDirIterator.IteratorFlags = QDirIterator.NoIteratorFlags", "PySide.QtCore.QString, PySide.QtCore.QStringList, PySide.QtCore.QDir.Filters = QDir.NoFilter, PySide.QtCore.QDirIterator.IteratorFlags = QDirIterator.NoIteratorFlags", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QDirIterator", overloads);
        return -1;
}

static PyObject* SbkQDirIteratorFunc_fileInfo(PyObject* self)
{
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;

    PyObject* py_result = 0;

    // fileInfo()const
    QDirIterator* cppSelf = Shiboken::Converter<QDirIterator* >::toCpp((PyObject*)self);
    QFileInfo cpp_result = cppSelf->QDirIterator::fileInfo();
    py_result = Shiboken::Converter<QFileInfo >::toPython(cpp_result);
    //CppGenerator::writeParentChildManagement

    if (PyErr_Occurred() || !py_result) {
        Py_XDECREF(py_result);
        return 0;
    }
    return py_result;
}

static PyObject* SbkQDirIteratorFunc_fileName(PyObject* self)
{
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;

    PyObject* py_result = 0;

    // fileName()const
    QDirIterator* cppSelf = Shiboken::Converter<QDirIterator* >::toCpp((PyObject*)self);
    QString cpp_result = cppSelf->QDirIterator::fileName();
    py_result = Shiboken::Converter<QString >::toPython(cpp_result);
    //CppGenerator::writeParentChildManagement

    if (PyErr_Occurred() || !py_result) {
        Py_XDECREF(py_result);
        return 0;
    }
    return py_result;
}

static PyObject* SbkQDirIteratorFunc_filePath(PyObject* self)
{
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;

    PyObject* py_result = 0;

    // filePath()const
    QDirIterator* cppSelf = Shiboken::Converter<QDirIterator* >::toCpp((PyObject*)self);
    QString cpp_result = cppSelf->QDirIterator::filePath();
    py_result = Shiboken::Converter<QString >::toPython(cpp_result);
    //CppGenerator::writeParentChildManagement

    if (PyErr_Occurred() || !py_result) {
        Py_XDECREF(py_result);
        return 0;
    }
    return py_result;
}

static PyObject* SbkQDirIteratorFunc_hasNext(PyObject* self)
{
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;

    PyObject* py_result = 0;

    // hasNext()const
    QDirIterator* cppSelf = Shiboken::Converter<QDirIterator* >::toCpp((PyObject*)self);
    bool cpp_result = cppSelf->QDirIterator::hasNext();
    py_result = Shiboken::Converter<bool >::toPython(cpp_result);
    //CppGenerator::writeParentChildManagement

    if (PyErr_Occurred() || !py_result) {
        Py_XDECREF(py_result);
        return 0;
    }
    return py_result;
}

static PyObject* SbkQDirIteratorFunc_next(PyObject* self)
{
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;

    PyObject* py_result = 0;

    // next()
    QDirIterator* cppSelf = Shiboken::Converter<QDirIterator* >::toCpp((PyObject*)self);
    QString cpp_result = cppSelf->QDirIterator::next();
    py_result = Shiboken::Converter<QString >::toPython(cpp_result);
    //CppGenerator::writeParentChildManagement

    if (PyErr_Occurred() || !py_result) {
        Py_XDECREF(py_result);
        return 0;
    }
    return py_result;
}

static PyObject* SbkQDirIteratorFunc_path(PyObject* self)
{
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;

    PyObject* py_result = 0;

    // path()const
    QDirIterator* cppSelf = Shiboken::Converter<QDirIterator* >::toCpp((PyObject*)self);
    QString cpp_result = cppSelf->QDirIterator::path();
    py_result = Shiboken::Converter<QString >::toPython(cpp_result);
    //CppGenerator::writeParentChildManagement

    if (PyErr_Occurred() || !py_result) {
        Py_XDECREF(py_result);
        return 0;
    }
    return py_result;
}

static PyMethodDef SbkQDirIterator_methods[] = {
    {"fileInfo", (PyCFunction)SbkQDirIteratorFunc_fileInfo, METH_NOARGS},
    {"fileName", (PyCFunction)SbkQDirIteratorFunc_fileName, METH_NOARGS},
    {"filePath", (PyCFunction)SbkQDirIteratorFunc_filePath, METH_NOARGS},
    {"hasNext", (PyCFunction)SbkQDirIteratorFunc_hasNext, METH_NOARGS},
    {"next", (PyCFunction)SbkQDirIteratorFunc_next, METH_NOARGS},
    {"path", (PyCFunction)SbkQDirIteratorFunc_path, METH_NOARGS},
    {0} // Sentinel
};

extern "C"
{

// Class Definition -----------------------------------------------
static SbkBaseWrapperType SbkQDirIterator_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtCore.QDirIterator",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQDirIterator_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQDirIterator_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QDirIterator >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0
};

static SbkBaseWrapperType* SbkQDirIterator_typeDiscovery(void* cptr, SbkBaseWrapperType* instanceType)
{
    if (instanceType->mi_specialcast)
        cptr = instanceType->mi_specialcast(cptr, &SbkQDirIterator_Type);
    TypeResolver* typeResolver = TypeResolver::get(typeid(*reinterpret_cast<QDirIterator*>(cptr)).name());
    if (typeResolver)
        return reinterpret_cast<SbkBaseWrapperType*>(typeResolver->pythonType());
    return 0;
}

PyObject*
SbkPySide_QtCore_QDirIterator_IteratorFlag___and__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QDirIterator::IteratorFlags >::toPython(
        ((QDirIterator::IteratorFlags) ((SbkEnumObject*)self)->ob_ival)
        & Shiboken::Converter< QDirIterator::IteratorFlags >::toCpp(arg)
    );
}

PyObject*
SbkPySide_QtCore_QDirIterator_IteratorFlag___or__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QDirIterator::IteratorFlags >::toPython(
        ((QDirIterator::IteratorFlags) ((SbkEnumObject*)self)->ob_ival)
        | Shiboken::Converter< QDirIterator::IteratorFlags >::toCpp(arg)
    );
}

PyObject*
SbkPySide_QtCore_QDirIterator_IteratorFlag___xor__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QDirIterator::IteratorFlags >::toPython(
        ((QDirIterator::IteratorFlags) ((SbkEnumObject*)self)->ob_ival)
        ^ Shiboken::Converter< QDirIterator::IteratorFlags >::toCpp(arg)
    );
}

PyObject*
SbkPySide_QtCore_QDirIterator_IteratorFlag___invert__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QDirIterator::IteratorFlags >::toPython(
        ~ Shiboken::Converter< QDirIterator::IteratorFlags >::toCpp(self)
    );
}


static PyNumberMethods SbkPySide_QtCore_QDirIterator_IteratorFlag_as_number = {
    /*nb_add*/                  0,
    /*nb_subtract*/             0,
    /*nb_multiply*/             0,
    /*nb_divide*/               0,
    /*nb_remainder*/            0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             0,
    /*nb_positive*/             0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              0,
    /*nb_invert*/               (unaryfunc)SbkPySide_QtCore_QDirIterator_IteratorFlag___invert__,
    /*nb_lshift*/               0,
    /*nb_rshift*/               0,
    /*nb_and*/                  (binaryfunc)SbkPySide_QtCore_QDirIterator_IteratorFlag___and__,
    /*nb_xor*/                  (binaryfunc)SbkPySide_QtCore_QDirIterator_IteratorFlag___xor__,
    /*nb_or*/                   (binaryfunc)SbkPySide_QtCore_QDirIterator_IteratorFlag___or__,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          0,
    /*nb_inplace_subtract*/     0,
    /*nb_inplace_multiply*/     0,
    /*nb_inplace_divide*/       0,
    /*nb_inplace_remainder*/    0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       0,
    /*nb_inplace_rshift*/       0,
    /*nb_inplace_and*/          0,
    /*nb_inplace_xor*/          0,
    /*nb_inplace_or*/           0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};


static PyGetSetDef SbkPySide_QtCore_QDirIterator_IteratorFlag_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtCore_QDirIterator_IteratorFlag_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtCore_QDirIterator_IteratorFlag_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "IteratorFlag",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        &SbkPySide_QtCore_QDirIterator_IteratorFlag_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtCore_QDirIterator_IteratorFlag_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtCore_QDirIterator_IteratorFlag_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtCore_QDirIterator_IteratorFlag_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

// forward declaration of new function
static PyObject* SbkPySide_QtCore_QDirIterator_IteratorFlags_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtCore_QDirIterator_IteratorFlags_Type = {
    PyObject_HEAD_INIT(&PyType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "IteratorFlags",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             &SbkPySide_QtCore_QDirIterator_IteratorFlag_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtCore_QDirIterator_IteratorFlags_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtCore_QDirIterator_IteratorFlags_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    if (!PyType_IsSubtype(type, &SbkPySide_QtCore_QDirIterator_IteratorFlags_Type))
        return 0;

    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}



PyAPI_FUNC(void) init_QDirIterator(PyObject* module)
{
    SbkPySide_QtCoreTypes[SBK_QDIRITERATOR_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQDirIterator_Type);

    // Fill type discovery information
    SbkQDirIterator_Type.type_discovery = new Shiboken::TypeDiscovery;
    SbkQDirIterator_Type.type_discovery->addTypeDiscoveryFunction(&SbkQDirIterator_typeDiscovery);

    if (PyType_Ready((PyTypeObject*)&SbkQDirIterator_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQDirIterator_Type));
    PyModule_AddObject(module, "QDirIterator",
        ((PyObject*)&SbkQDirIterator_Type));

    // Initialize enums
    PyObject* enum_item;

    // init enum class: IteratorFlag
    SbkPySide_QtCoreTypes[SBK_QDIRITERATOR_ITERATORFLAG_IDX] = &SbkPySide_QtCore_QDirIterator_IteratorFlag_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtCore_QDirIterator_IteratorFlag_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtCore_QDirIterator_IteratorFlag_Type);
    PyDict_SetItemString(SbkQDirIterator_Type.super.ht_type.tp_dict,
            "IteratorFlag",((PyObject*)&SbkPySide_QtCore_QDirIterator_IteratorFlag_Type));

    // init flags class: QFlags<QDirIterator::IteratorFlag>
    SbkPySide_QtCoreTypes[SBK_QFLAGS_QDIRITERATOR_ITERATORFLAG__IDX] = &SbkPySide_QtCore_QDirIterator_IteratorFlags_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtCore_QDirIterator_IteratorFlags_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtCore_QDirIterator_IteratorFlags_Type);
    PyDict_SetItemString(SbkQDirIterator_Type.super.ht_type.tp_dict,
            "IteratorFlags",((PyObject*)&SbkPySide_QtCore_QDirIterator_IteratorFlags_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QDirIterator_IteratorFlag_Type,
        (long) QDirIterator::NoIteratorFlags, "NoIteratorFlags");
    PyDict_SetItemString(SbkQDirIterator_Type.super.ht_type.tp_dict,
        "NoIteratorFlags", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QDirIterator_IteratorFlag_Type.tp_dict,
        "NoIteratorFlags", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QDirIterator_IteratorFlag_Type,
        (long) QDirIterator::FollowSymlinks, "FollowSymlinks");
    PyDict_SetItemString(SbkQDirIterator_Type.super.ht_type.tp_dict,
        "FollowSymlinks", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QDirIterator_IteratorFlag_Type.tp_dict,
        "FollowSymlinks", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QDirIterator_IteratorFlag_Type,
        (long) QDirIterator::Subdirectories, "Subdirectories");
    PyDict_SetItemString(SbkQDirIterator_Type.super.ht_type.tp_dict,
        "Subdirectories", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QDirIterator_IteratorFlag_Type.tp_dict,
        "Subdirectories", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QDirIterator::IteratorFlag");

    Shiboken::TypeResolver::createObjectTypeResolver<QDirIterator >("QDirIterator*");
    Shiboken::TypeResolver::createObjectTypeResolver<QDirIterator >(typeid(QDirIterator).name());
}


} // extern "C"

