/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtcore_python.h"

#include "qdynamicpropertychangeevent_wrapper.h"

// Extra includes
#include <qbytearray.h>

using namespace Shiboken;

// Native ---------------------------------------------------------

QDynamicPropertyChangeEventWrapper::QDynamicPropertyChangeEventWrapper(const QByteArray & name) : QDynamicPropertyChangeEvent(name) {
    // ... middle
}

QDynamicPropertyChangeEventWrapper::~QDynamicPropertyChangeEventWrapper()
{
    BindingManager::instance().invalidateWrapper(this);
}

// Target ---------------------------------------------------------

static int
SbkQDynamicPropertyChangeEvent_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    QDynamicPropertyChangeEventWrapper* cptr = 0;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    if (!PyArg_UnpackTuple(args, "QDynamicPropertyChangeEvent", 1, 1, &(pyargs[0])))
        return -1;

    if (numArgs == 1 && Shiboken::Converter<QByteArray & >::isConvertible(pyargs[0])) {
        if (Shiboken::cppObjectIsInvalid(pyargs[0]))
            return -1;
        std::auto_ptr<QByteArray > cpp_arg0_auto_ptr;
        QByteArray* cpp_arg0 = Shiboken::Converter<QByteArray* >::toCpp(pyargs[0]);
        if (!SbkQByteArray_Check(pyargs[0]))
            cpp_arg0_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg0);
        // QDynamicPropertyChangeEvent(QByteArray)
        cptr = new QDynamicPropertyChangeEventWrapper(*cpp_arg0);
        //CppGenerator::writeParentChildManagement
    } else goto SbkQDynamicPropertyChangeEvent_Init_TypeError;

    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QDynamicPropertyChangeEvent >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQDynamicPropertyChangeEvent_Init_TypeError;

    sbkSelf->validCppObject = 1;
    sbkSelf->containsCppWrapper = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);

    return 1;

    SbkQDynamicPropertyChangeEvent_Init_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QDynamicPropertyChangeEvent", overloads);
        return -1;
}

static PyObject* SbkQDynamicPropertyChangeEventFunc_propertyName(PyObject* self)
{
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;

    PyObject* py_result = 0;

    // propertyName()const
    QDynamicPropertyChangeEvent* cppSelf = Shiboken::Converter<QDynamicPropertyChangeEvent* >::toCpp((PyObject*)self);
    QByteArray cpp_result = cppSelf->QDynamicPropertyChangeEvent::propertyName();
    py_result = Shiboken::Converter<QByteArray >::toPython(cpp_result);
    //CppGenerator::writeParentChildManagement

    if (PyErr_Occurred() || !py_result) {
        Py_XDECREF(py_result);
        return 0;
    }
    return py_result;
}

static PyMethodDef SbkQDynamicPropertyChangeEvent_methods[] = {
    {"propertyName", (PyCFunction)SbkQDynamicPropertyChangeEventFunc_propertyName, METH_NOARGS},
    {0} // Sentinel
};

extern "C"
{

// Class Definition -----------------------------------------------
static SbkBaseWrapperType SbkQDynamicPropertyChangeEvent_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtCore.QDynamicPropertyChangeEvent",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQDynamicPropertyChangeEvent_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQDynamicPropertyChangeEvent_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QDynamicPropertyChangeEvent >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0
};

static SbkBaseWrapperType* SbkQDynamicPropertyChangeEvent_typeDiscovery(void* cptr, SbkBaseWrapperType* instanceType)
{
    if (instanceType->mi_specialcast)
        cptr = instanceType->mi_specialcast(cptr, &SbkQDynamicPropertyChangeEvent_Type);
     if ( reinterpret_cast<QDynamicPropertyChangeEvent*>(cptr)->type() == QEvent::DynamicPropertyChange)
        return &SbkQDynamicPropertyChangeEvent_Type;
    return 0;
}


PyAPI_FUNC(void) init_QDynamicPropertyChangeEvent(PyObject* module)
{
    SbkPySide_QtCoreTypes[SBK_QDYNAMICPROPERTYCHANGEEVENT_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQDynamicPropertyChangeEvent_Type);

    SbkQDynamicPropertyChangeEvent_Type.super.ht_type.tp_base = SbkPySide_QtCoreTypes[SBK_QEVENT_IDX];
    // Fill type discovery information
    SbkQDynamicPropertyChangeEvent_Type.type_discovery = reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtCoreTypes[SBK_QEVENT_IDX])->type_discovery;
    SbkQDynamicPropertyChangeEvent_Type.type_discovery->addTypeDiscoveryFunction(&SbkQDynamicPropertyChangeEvent_typeDiscovery);

    if (PyType_Ready((PyTypeObject*)&SbkQDynamicPropertyChangeEvent_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQDynamicPropertyChangeEvent_Type));
    PyModule_AddObject(module, "QDynamicPropertyChangeEvent",
        ((PyObject*)&SbkQDynamicPropertyChangeEvent_Type));

    Shiboken::TypeResolver::createObjectTypeResolver<QDynamicPropertyChangeEvent >("QDynamicPropertyChangeEvent*");
    Shiboken::TypeResolver::createObjectTypeResolver<QDynamicPropertyChangeEvent >(typeid(QDynamicPropertyChangeEvent).name());
}


} // extern "C"

