/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtcore_python.h"

#include "qmodelindex_wrapper.h"

// Extra includes
#include <qabstractitemmodel.h>
#include <qvariant.h>

using namespace Shiboken;

static int
SbkQModelIndex_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    QModelIndex* cptr = 0;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    if (!PyArg_UnpackTuple(args, "QModelIndex", 0, 1, &(pyargs[0])))
        return -1;

    if (numArgs == 0) {
        // QModelIndex()
        cptr = new QModelIndex();
        //CppGenerator::writeParentChildManagement
    } else if (numArgs == 1 && Shiboken::Converter<QModelIndex & >::isConvertible(pyargs[0])) {
        if (Shiboken::cppObjectIsInvalid(pyargs[0]))
            return -1;
        QModelIndex* cpp_arg0 = Shiboken::Converter<QModelIndex* >::toCpp(pyargs[0]);
        // QModelIndex(QModelIndex)
        cptr = new QModelIndex(*cpp_arg0);
        //CppGenerator::writeParentChildManagement
    } else goto SbkQModelIndex_Init_TypeError;

    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QModelIndex >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQModelIndex_Init_TypeError;

    sbkSelf->validCppObject = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);

    return 1;

    SbkQModelIndex_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtCore.QModelIndex", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QModelIndex", overloads);
        return -1;
}

static PyObject* SbkQModelIndexFunc_child(PyObject* self, PyObject* args)
{
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;

    PyObject* py_result = 0;

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    if (!PyArg_UnpackTuple(args, "child", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;

    if (numArgs == 2 && PyNumber_Check(pyargs[0]) && PyNumber_Check(pyargs[1])) {
        int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
        int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
        // child(int,int)const
        QModelIndex* cppSelf = Shiboken::Converter<QModelIndex* >::toCpp((PyObject*)self);
        QModelIndex cpp_result = cppSelf->QModelIndex::child(cpp_arg0, cpp_arg1);
        py_result = Shiboken::Converter<QModelIndex >::toPython(cpp_result);
        //CppGenerator::writeParentChildManagement
    } else goto SbkQModelIndexFunc_child_TypeError;

    if (PyErr_Occurred() || !py_result) {
        Py_XDECREF(py_result);
        return 0;
    }
    return py_result;

    SbkQModelIndexFunc_child_TypeError:
        const char* overloads[] = {"int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QModelIndex.child", overloads);
        return 0;
}

static PyObject* SbkQModelIndexFunc_column(PyObject* self)
{
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;

    PyObject* py_result = 0;

    // column()const
    QModelIndex* cppSelf = Shiboken::Converter<QModelIndex* >::toCpp((PyObject*)self);
    int cpp_result = cppSelf->QModelIndex::column();
    py_result = Shiboken::Converter<int >::toPython(cpp_result);
    //CppGenerator::writeParentChildManagement

    if (PyErr_Occurred() || !py_result) {
        Py_XDECREF(py_result);
        return 0;
    }
    return py_result;
}

static PyObject* SbkQModelIndexFunc_data(PyObject* self, PyObject* arg)
{
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;

    PyObject* py_result = 0;

    int numArgs = (arg == 0 ? 0 : 1);
    if (numArgs == 0) {
        // data(int)const
        QModelIndex* cppSelf = Shiboken::Converter<QModelIndex* >::toCpp((PyObject*)self);
        QVariant cpp_result = cppSelf->QModelIndex::data();
        py_result = Shiboken::Converter<QVariant >::toPython(cpp_result);
        //CppGenerator::writeParentChildManagement
    } else if (PyNumber_Check(arg)) {
        int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);
        // data(int)const
        QModelIndex* cppSelf = Shiboken::Converter<QModelIndex* >::toCpp((PyObject*)self);
        QVariant cpp_result = cppSelf->QModelIndex::data(cpp_arg0);
        py_result = Shiboken::Converter<QVariant >::toPython(cpp_result);
        //CppGenerator::writeParentChildManagement
    } else goto SbkQModelIndexFunc_data_TypeError;

    if (PyErr_Occurred() || !py_result) {
        Py_XDECREF(py_result);
        return 0;
    }
    return py_result;

    SbkQModelIndexFunc_data_TypeError:
        const char* overloads[] = {"int = Qt.DisplayRole", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QModelIndex.data", overloads);
        return 0;
}

static PyObject* SbkQModelIndexFunc_flags(PyObject* self)
{
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;

    PyObject* py_result = 0;

    // flags()const
    QModelIndex* cppSelf = Shiboken::Converter<QModelIndex* >::toCpp((PyObject*)self);
    QFlags<Qt::ItemFlag> cpp_result = cppSelf->QModelIndex::flags();
    py_result = Shiboken::Converter<QFlags<Qt::ItemFlag> >::toPython(cpp_result);
    //CppGenerator::writeParentChildManagement

    if (PyErr_Occurred() || !py_result) {
        Py_XDECREF(py_result);
        return 0;
    }
    return py_result;
}

static PyObject* SbkQModelIndexFunc_internalId(PyObject* self)
{
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;

    PyObject* py_result = 0;

    // internalId()const
    QModelIndex* cppSelf = Shiboken::Converter<QModelIndex* >::toCpp((PyObject*)self);
    qint64 cpp_result = cppSelf->QModelIndex::internalId();
    py_result = Shiboken::Converter<long long >::toPython(cpp_result);
    //CppGenerator::writeParentChildManagement

    if (PyErr_Occurred() || !py_result) {
        Py_XDECREF(py_result);
        return 0;
    }
    return py_result;
}

static PyObject* SbkQModelIndexFunc_internalPointer(PyObject* self)
{
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;

    PyObject* py_result = 0;

    // internalPointer()const
    QModelIndex* cppSelf = Shiboken::Converter<QModelIndex* >::toCpp((PyObject*)self);
    // Begin code injection
    
    py_result = (PyObject*)cppSelf->internalPointer();
    if (!py_result)
        py_result = Py_None;
    Py_XINCREF(py_result);
    
    // End of code injection


    //CppGenerator::writeParentChildManagement

    if (PyErr_Occurred() || !py_result) {
        Py_XDECREF(py_result);
        return 0;
    }
    return py_result;
}

static PyObject* SbkQModelIndexFunc_isValid(PyObject* self)
{
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;

    PyObject* py_result = 0;

    // isValid()const
    QModelIndex* cppSelf = Shiboken::Converter<QModelIndex* >::toCpp((PyObject*)self);
    bool cpp_result = cppSelf->QModelIndex::isValid();
    py_result = Shiboken::Converter<bool >::toPython(cpp_result);
    //CppGenerator::writeParentChildManagement

    if (PyErr_Occurred() || !py_result) {
        Py_XDECREF(py_result);
        return 0;
    }
    return py_result;
}

static PyObject* SbkQModelIndexFunc_model(PyObject* self)
{
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;

    PyObject* py_result = 0;

    // model()const
    QModelIndex* cppSelf = Shiboken::Converter<QModelIndex* >::toCpp((PyObject*)self);
    const QAbstractItemModel * cpp_result = cppSelf->QModelIndex::model();
    py_result = Shiboken::Converter<QAbstractItemModel * >::toPython(cpp_result);
    //CppGenerator::writeParentChildManagement
    Shiboken::setParent(self, py_result);

    if (PyErr_Occurred() || !py_result) {
        Py_XDECREF(py_result);
        return 0;
    }
    return py_result;
}

static PyObject* SbkQModelIndexFunc_parent(PyObject* self)
{
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;

    PyObject* py_result = 0;

    // parent()const
    QModelIndex* cppSelf = Shiboken::Converter<QModelIndex* >::toCpp((PyObject*)self);
    QModelIndex cpp_result = cppSelf->QModelIndex::parent();
    py_result = Shiboken::Converter<QModelIndex >::toPython(cpp_result);
    //CppGenerator::writeParentChildManagement

    if (PyErr_Occurred() || !py_result) {
        Py_XDECREF(py_result);
        return 0;
    }
    return py_result;
}

static PyObject* SbkQModelIndexFunc_row(PyObject* self)
{
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;

    PyObject* py_result = 0;

    // row()const
    QModelIndex* cppSelf = Shiboken::Converter<QModelIndex* >::toCpp((PyObject*)self);
    int cpp_result = cppSelf->QModelIndex::row();
    py_result = Shiboken::Converter<int >::toPython(cpp_result);
    //CppGenerator::writeParentChildManagement

    if (PyErr_Occurred() || !py_result) {
        Py_XDECREF(py_result);
        return 0;
    }
    return py_result;
}

static PyObject* SbkQModelIndexFunc_sibling(PyObject* self, PyObject* args)
{
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;

    PyObject* py_result = 0;

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    if (!PyArg_UnpackTuple(args, "sibling", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;

    if (numArgs == 2 && PyNumber_Check(pyargs[0]) && PyNumber_Check(pyargs[1])) {
        int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
        int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
        // sibling(int,int)const
        QModelIndex* cppSelf = Shiboken::Converter<QModelIndex* >::toCpp((PyObject*)self);
        QModelIndex cpp_result = cppSelf->QModelIndex::sibling(cpp_arg0, cpp_arg1);
        py_result = Shiboken::Converter<QModelIndex >::toPython(cpp_result);
        //CppGenerator::writeParentChildManagement
    } else goto SbkQModelIndexFunc_sibling_TypeError;

    if (PyErr_Occurred() || !py_result) {
        Py_XDECREF(py_result);
        return 0;
    }
    return py_result;

    SbkQModelIndexFunc_sibling_TypeError:
        const char* overloads[] = {"int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QModelIndex.sibling", overloads);
        return 0;
}

static PyMethodDef SbkQModelIndex_methods[] = {
    {"child", (PyCFunction)SbkQModelIndexFunc_child, METH_VARARGS},
    {"column", (PyCFunction)SbkQModelIndexFunc_column, METH_NOARGS},
    {"data", (PyCFunction)SbkQModelIndexFunc_data, METH_NOARGS|METH_O},
    {"flags", (PyCFunction)SbkQModelIndexFunc_flags, METH_NOARGS},
    {"internalId", (PyCFunction)SbkQModelIndexFunc_internalId, METH_NOARGS},
    {"internalPointer", (PyCFunction)SbkQModelIndexFunc_internalPointer, METH_NOARGS},
    {"isValid", (PyCFunction)SbkQModelIndexFunc_isValid, METH_NOARGS},
    {"model", (PyCFunction)SbkQModelIndexFunc_model, METH_NOARGS},
    {"parent", (PyCFunction)SbkQModelIndexFunc_parent, METH_NOARGS},
    {"row", (PyCFunction)SbkQModelIndexFunc_row, METH_NOARGS},
    {"sibling", (PyCFunction)SbkQModelIndexFunc_sibling, METH_VARARGS},
    {0} // Sentinel
};

// Rich comparison
static PyObject* SbkQModelIndex_richcompare(PyObject* self, PyObject* other, int op)
{
    bool result = false;
    QModelIndex& cpp_self = *Shiboken::Converter<QModelIndex* >::toCpp((PyObject*)self);

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter<QModelIndex & >::isConvertible(other)) {
                // operator!=(const QModelIndex & other) const
                QModelIndex* cpp_other = Shiboken::Converter<QModelIndex* >::toCpp((PyObject*)other);
                result = !cpp_other ? cpp_self == Shiboken::Converter<QModelIndex  >::toCpp(other) : (cpp_self != (*cpp_other));
            } else goto SbkQModelIndex_RichComparison_TypeError;

            break;
        case Py_LT:
            if (Shiboken::Converter<QModelIndex & >::isConvertible(other)) {
                // operator<(const QModelIndex & other) const
                QModelIndex* cpp_other = Shiboken::Converter<QModelIndex* >::toCpp((PyObject*)other);
                result = !cpp_other ? cpp_self == Shiboken::Converter<QModelIndex  >::toCpp(other) : (cpp_self < (*cpp_other));
            } else goto SbkQModelIndex_RichComparison_TypeError;

            break;
        case Py_EQ:
            if (Shiboken::Converter<QModelIndex & >::isConvertible(other)) {
                // operator==(const QModelIndex & other) const
                QModelIndex* cpp_other = Shiboken::Converter<QModelIndex* >::toCpp((PyObject*)other);
                result = !cpp_other ? cpp_self == Shiboken::Converter<QModelIndex  >::toCpp(other) : (cpp_self == (*cpp_other));
            } else goto SbkQModelIndex_RichComparison_TypeError;

            break;
        default:
            PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
            return 0;
    }

    if (result)
        Py_RETURN_TRUE;
    SbkQModelIndex_RichComparison_TypeError:
    Py_RETURN_FALSE;

}

extern "C"
{

// Class Definition -----------------------------------------------
static SbkBaseWrapperType SbkQModelIndex_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtCore.QModelIndex",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      SbkQModelIndex_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQModelIndex_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQModelIndex_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QModelIndex >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0
};


PyAPI_FUNC(void) init_QModelIndex(PyObject* module)
{
    SbkPySide_QtCoreTypes[SBK_QMODELINDEX_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQModelIndex_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQModelIndex_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQModelIndex_Type));
    PyModule_AddObject(module, "QModelIndex",
        ((PyObject*)&SbkQModelIndex_Type));

    Shiboken::TypeResolver::createValueTypeResolver<QModelIndex >("QModelIndex");
    Shiboken::TypeResolver::createValueTypeResolver<QModelIndex >(typeid(QModelIndex).name());
}


} // extern "C"

