/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtcore_python.h"

#include "qwritelocker_wrapper.h"

// Extra includes
#include <qreadwritelock.h>

using namespace Shiboken;

static int
SbkQWriteLocker_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    QWriteLocker* cptr = 0;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    if (!PyArg_UnpackTuple(args, "QWriteLocker", 1, 1, &(pyargs[0])))
        return -1;

    if (numArgs == 1 && Shiboken::Converter<QReadWriteLock * >::isConvertible(pyargs[0])) {
        if (Shiboken::cppObjectIsInvalid(pyargs[0]))
            return -1;
        QReadWriteLock* cpp_arg0 = Shiboken::Converter<QReadWriteLock* >::toCpp(pyargs[0]);
        // QWriteLocker(QReadWriteLock*)
        cptr = new QWriteLocker(cpp_arg0);
        //CppGenerator::writeParentChildManagement
    } else goto SbkQWriteLocker_Init_TypeError;

    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QWriteLocker >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQWriteLocker_Init_TypeError;

    sbkSelf->validCppObject = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);

    return 1;

    SbkQWriteLocker_Init_TypeError:
        const char* overloads[] = {"PySide.QtCore.QReadWriteLock", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QWriteLocker", overloads);
        return -1;
}

static PyObject* SbkQWriteLockerFunc_readWriteLock(PyObject* self)
{
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;

    PyObject* py_result = 0;

    // readWriteLock()const
    QWriteLocker* cppSelf = Shiboken::Converter<QWriteLocker* >::toCpp((PyObject*)self);
    QReadWriteLock * cpp_result = cppSelf->QWriteLocker::readWriteLock();
    py_result = Shiboken::Converter<QReadWriteLock * >::toPython(cpp_result);
    //CppGenerator::writeParentChildManagement
    Shiboken::setParent(self, py_result);

    if (PyErr_Occurred() || !py_result) {
        Py_XDECREF(py_result);
        return 0;
    }
    return py_result;
}

static PyObject* SbkQWriteLockerFunc_relock(PyObject* self)
{
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;

    Shiboken::ThreadStateSaver thread_state_saver;

    // relock()
    QWriteLocker* cppSelf = Shiboken::Converter<QWriteLocker* >::toCpp((PyObject*)self);
    thread_state_saver.save();
    cppSelf->QWriteLocker::relock();
    thread_state_saver.restore();
    //CppGenerator::writeParentChildManagement

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQWriteLockerFunc_unlock(PyObject* self)
{
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;


    // unlock()
    QWriteLocker* cppSelf = Shiboken::Converter<QWriteLocker* >::toCpp((PyObject*)self);
    cppSelf->QWriteLocker::unlock();
    //CppGenerator::writeParentChildManagement

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyMethodDef SbkQWriteLocker_methods[] = {
    {"readWriteLock", (PyCFunction)SbkQWriteLockerFunc_readWriteLock, METH_NOARGS},
    {"relock", (PyCFunction)SbkQWriteLockerFunc_relock, METH_NOARGS},
    {"unlock", (PyCFunction)SbkQWriteLockerFunc_unlock, METH_NOARGS},
    {0} // Sentinel
};

extern "C"
{

// Class Definition -----------------------------------------------
static SbkBaseWrapperType SbkQWriteLocker_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtCore.QWriteLocker",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQWriteLocker_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQWriteLocker_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QWriteLocker >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0
};


PyAPI_FUNC(void) init_QWriteLocker(PyObject* module)
{
    SbkPySide_QtCoreTypes[SBK_QWRITELOCKER_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQWriteLocker_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQWriteLocker_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQWriteLocker_Type));
    PyModule_AddObject(module, "QWriteLocker",
        ((PyObject*)&SbkQWriteLocker_Type));

    Shiboken::TypeResolver::createObjectTypeResolver<QWriteLocker >("QWriteLocker*");
    Shiboken::TypeResolver::createObjectTypeResolver<QWriteLocker >(typeid(QWriteLocker).name());
}


} // extern "C"

