/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qinputevent_wrapper.h"

// Extra includes

using namespace Shiboken;

// Native ---------------------------------------------------------

QInputEventWrapper::QInputEventWrapper(QEvent::Type type, QFlags<Qt::KeyboardModifier> modifiers) : QInputEvent(type, modifiers) {
    // ... middle
}

QInputEventWrapper::~QInputEventWrapper()
{
    BindingManager::instance().invalidateWrapper(this);
}

// Target ---------------------------------------------------------

static int
SbkQInputEvent_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    QInputEventWrapper* cptr = 0;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    if (!PyArg_UnpackTuple(args, "QInputEvent", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return -1;

    if (Shiboken::Converter<QEvent::Type >::isConvertible(pyargs[0])) {
        QEvent::Type cpp_arg0 = Shiboken::Converter<QEvent::Type >::toCpp(pyargs[0]);
        if (numArgs == 1) {
            // QInputEvent(QEvent::Type,QFlags<Qt::KeyboardModifier>)
            cptr = new QInputEventWrapper(cpp_arg0);
            //CppGenerator::writeParentChildManagement
        } else if (SbkPySide_QtCore_Qt_KeyboardModifier_Check(pyargs[1])) {
            QFlags<Qt::KeyboardModifier> cpp_arg1 = Shiboken::Converter<QFlags<Qt::KeyboardModifier> >::toCpp(pyargs[1]);
            // QInputEvent(QEvent::Type,QFlags<Qt::KeyboardModifier>)
            cptr = new QInputEventWrapper(cpp_arg0, cpp_arg1);
            //CppGenerator::writeParentChildManagement
        } else goto SbkQInputEvent_Init_TypeError;
    } else goto SbkQInputEvent_Init_TypeError;

    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QInputEvent >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQInputEvent_Init_TypeError;

    sbkSelf->validCppObject = 1;
    sbkSelf->containsCppWrapper = 1;
    sbkSelf->referredObjects = new Shiboken::RefCountMap;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);

    return 1;

    SbkQInputEvent_Init_TypeError:
        const char* overloads[] = {"PySide.QtCore.QEvent.Type, PySide.QtCore.Qt.KeyboardModifiers = Qt.NoModifier", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QInputEvent", overloads);
        return -1;
}

static PyObject* SbkQInputEventFunc_modifiers(PyObject* self)
{
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;

    PyObject* py_result = 0;

    // modifiers()const
    QInputEvent* cppSelf = Shiboken::Converter<QInputEvent* >::toCpp((PyObject*)self);
    QFlags<Qt::KeyboardModifier> cpp_result = cppSelf->QInputEvent::modifiers();
    py_result = Shiboken::Converter<QFlags<Qt::KeyboardModifier> >::toPython(cpp_result);
    //CppGenerator::writeParentChildManagement

    if (PyErr_Occurred() || !py_result) {
        Py_XDECREF(py_result);
        return 0;
    }
    return py_result;
}

static PyObject* SbkQInputEventFunc_setModifiers(PyObject* self, PyObject* arg)
{
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;


    if (SbkPySide_QtCore_Qt_KeyboardModifier_Check(arg)) {
        QFlags<Qt::KeyboardModifier> cpp_arg0 = Shiboken::Converter<QFlags<Qt::KeyboardModifier> >::toCpp(arg);
        // setModifiers(QFlags<Qt::KeyboardModifier>)
        QInputEvent* cppSelf = Shiboken::Converter<QInputEvent* >::toCpp((PyObject*)self);
        cppSelf->QInputEvent::setModifiers(cpp_arg0);
        //CppGenerator::writeParentChildManagement
    } else goto SbkQInputEventFunc_setModifiers_TypeError;

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQInputEventFunc_setModifiers_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.KeyboardModifiers", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QInputEvent.setModifiers", overloads);
        return 0;
}

static PyMethodDef SbkQInputEvent_methods[] = {
    {"modifiers", (PyCFunction)SbkQInputEventFunc_modifiers, METH_NOARGS},
    {"setModifiers", (PyCFunction)SbkQInputEventFunc_setModifiers, METH_O},
    {0} // Sentinel
};

static PyObject* SbkQInputEvent_get_modState(SbkBaseWrapper* self)
{
    return Shiboken::Converter<QFlags<Qt::KeyboardModifier> >::toPython(Shiboken::Converter<QInputEvent* >::toCpp((PyObject*)self)->modState);
}
static int SbkQInputEvent_set_modState(SbkBaseWrapper* self, PyObject* value)
{
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'modState' may not be deleted");
        return -1;
    }
    if (!SbkPySide_QtCore_Qt_KeyboardModifier_Check(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'modState', 'KeyboardModifiers' or convertible type expected");
        return -1;
    }

    Shiboken::Converter<QInputEvent* >::toCpp((PyObject*)self)->modState = Shiboken::Converter<QFlags<Qt::KeyboardModifier> >::toCpp(value);

    return 0;
}

// Getters and Setters for QInputEvent
static PyGetSetDef SbkQInputEvent_getsetlist[] = {
    {const_cast<char*>("modState"), (getter)SbkQInputEvent_get_modState, (setter)SbkQInputEvent_set_modState},
    {0}  // Sentinel
};

extern "C"
{

// Class Definition -----------------------------------------------
static SbkBaseWrapperType SbkQInputEvent_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QInputEvent",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQInputEvent_methods,
    /*tp_members*/          0,
    /*tp_getset*/           SbkQInputEvent_getsetlist,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQInputEvent_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QInputEvent >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0
};


PyAPI_FUNC(void) init_QInputEvent(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QINPUTEVENT_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQInputEvent_Type);

    SbkQInputEvent_Type.super.ht_type.tp_base = SbkPySide_QtCoreTypes[SBK_QEVENT_IDX];
    // Fill type discovery information
    SbkQInputEvent_Type.type_discovery = reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtCoreTypes[SBK_QEVENT_IDX])->type_discovery;

    if (PyType_Ready((PyTypeObject*)&SbkQInputEvent_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQInputEvent_Type));
    PyModule_AddObject(module, "QInputEvent",
        ((PyObject*)&SbkQInputEvent_Type));

    Shiboken::TypeResolver::createObjectTypeResolver<QInputEvent >("QInputEvent*");
    Shiboken::TypeResolver::createObjectTypeResolver<QInputEvent >(typeid(QInputEvent).name());
}


} // extern "C"

