/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qresizeevent_wrapper.h"

// Extra includes
#include <qsize.h>

using namespace Shiboken;

// Native ---------------------------------------------------------

QResizeEventWrapper::QResizeEventWrapper(const QSize & size, const QSize & oldSize) : QResizeEvent(size, oldSize) {
    // ... middle
}

QResizeEventWrapper::~QResizeEventWrapper()
{
    BindingManager::instance().invalidateWrapper(this);
}

// Target ---------------------------------------------------------

static int
SbkQResizeEvent_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    QResizeEventWrapper* cptr = 0;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    if (!PyArg_UnpackTuple(args, "QResizeEvent", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return -1;

    if (numArgs == 2 && Shiboken::Converter<QSize & >::isConvertible(pyargs[0]) && Shiboken::Converter<QSize & >::isConvertible(pyargs[1])) {
        if (Shiboken::cppObjectIsInvalid(pyargs[0]))
            return -1;
        QSize* cpp_arg0 = Shiboken::Converter<QSize* >::toCpp(pyargs[0]);
        if (Shiboken::cppObjectIsInvalid(pyargs[1]))
            return -1;
        QSize* cpp_arg1 = Shiboken::Converter<QSize* >::toCpp(pyargs[1]);
        // QResizeEvent(QSize,QSize)
        cptr = new QResizeEventWrapper(*cpp_arg0, *cpp_arg1);
        //CppGenerator::writeParentChildManagement
    } else goto SbkQResizeEvent_Init_TypeError;

    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QResizeEvent >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQResizeEvent_Init_TypeError;

    sbkSelf->validCppObject = 1;
    sbkSelf->containsCppWrapper = 1;
    sbkSelf->referredObjects = new Shiboken::RefCountMap;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);

    return 1;

    SbkQResizeEvent_Init_TypeError:
        const char* overloads[] = {"PySide.QtCore.QSize, PySide.QtCore.QSize", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QResizeEvent", overloads);
        return -1;
}

static PyObject* SbkQResizeEventFunc_oldSize(PyObject* self)
{
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;

    PyObject* py_result = 0;

    // oldSize()const
    QResizeEvent* cppSelf = Shiboken::Converter<QResizeEvent* >::toCpp((PyObject*)self);
    const QSize & cpp_result = cppSelf->QResizeEvent::oldSize();
    py_result = Shiboken::Converter<QSize & >::toPython(cpp_result);
    //CppGenerator::writeParentChildManagement

    if (PyErr_Occurred() || !py_result) {
        Py_XDECREF(py_result);
        return 0;
    }
    return py_result;
}

static PyObject* SbkQResizeEventFunc_size(PyObject* self)
{
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;

    PyObject* py_result = 0;

    // size()const
    QResizeEvent* cppSelf = Shiboken::Converter<QResizeEvent* >::toCpp((PyObject*)self);
    const QSize & cpp_result = cppSelf->QResizeEvent::size();
    py_result = Shiboken::Converter<QSize & >::toPython(cpp_result);
    //CppGenerator::writeParentChildManagement

    if (PyErr_Occurred() || !py_result) {
        Py_XDECREF(py_result);
        return 0;
    }
    return py_result;
}

static PyMethodDef SbkQResizeEvent_methods[] = {
    {"oldSize", (PyCFunction)SbkQResizeEventFunc_oldSize, METH_NOARGS},
    {"size", (PyCFunction)SbkQResizeEventFunc_size, METH_NOARGS},
    {0} // Sentinel
};

static PyObject* SbkQResizeEvent_get_olds(SbkBaseWrapper* self)
{
    return Shiboken::Converter<QSize >::toPython(Shiboken::Converter<QResizeEvent* >::toCpp((PyObject*)self)->olds);
}
static int SbkQResizeEvent_set_olds(SbkBaseWrapper* self, PyObject* value)
{
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'olds' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter<QSize >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'olds', 'QSize' or convertible type expected");
        return -1;
    }

    Shiboken::Converter<QResizeEvent* >::toCpp((PyObject*)self)->olds = Shiboken::Converter<QSize >::toCpp(value);

    return 0;
}

static PyObject* SbkQResizeEvent_get_s(SbkBaseWrapper* self)
{
    return Shiboken::Converter<QSize >::toPython(Shiboken::Converter<QResizeEvent* >::toCpp((PyObject*)self)->s);
}
static int SbkQResizeEvent_set_s(SbkBaseWrapper* self, PyObject* value)
{
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'s' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter<QSize >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 's', 'QSize' or convertible type expected");
        return -1;
    }

    Shiboken::Converter<QResizeEvent* >::toCpp((PyObject*)self)->s = Shiboken::Converter<QSize >::toCpp(value);

    return 0;
}

// Getters and Setters for QResizeEvent
static PyGetSetDef SbkQResizeEvent_getsetlist[] = {
    {const_cast<char*>("olds"), (getter)SbkQResizeEvent_get_olds, (setter)SbkQResizeEvent_set_olds},
    {const_cast<char*>("s"), (getter)SbkQResizeEvent_get_s, (setter)SbkQResizeEvent_set_s},
    {0}  // Sentinel
};

extern "C"
{

// Class Definition -----------------------------------------------
static SbkBaseWrapperType SbkQResizeEvent_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QResizeEvent",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQResizeEvent_methods,
    /*tp_members*/          0,
    /*tp_getset*/           SbkQResizeEvent_getsetlist,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQResizeEvent_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QResizeEvent >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0
};

static SbkBaseWrapperType* SbkQResizeEvent_typeDiscovery(void* cptr, SbkBaseWrapperType* instanceType)
{
    if (instanceType->mi_specialcast)
        cptr = instanceType->mi_specialcast(cptr, &SbkQResizeEvent_Type);
     if ( reinterpret_cast<QResizeEvent*>(cptr)->type() == QEvent::Resize)
        return &SbkQResizeEvent_Type;
    return 0;
}


PyAPI_FUNC(void) init_QResizeEvent(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QRESIZEEVENT_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQResizeEvent_Type);

    SbkQResizeEvent_Type.super.ht_type.tp_base = SbkPySide_QtCoreTypes[SBK_QEVENT_IDX];
    // Fill type discovery information
    SbkQResizeEvent_Type.type_discovery = reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtCoreTypes[SBK_QEVENT_IDX])->type_discovery;
    SbkQResizeEvent_Type.type_discovery->addTypeDiscoveryFunction(&SbkQResizeEvent_typeDiscovery);

    if (PyType_Ready((PyTypeObject*)&SbkQResizeEvent_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQResizeEvent_Type));
    PyModule_AddObject(module, "QResizeEvent",
        ((PyObject*)&SbkQResizeEvent_Type));

    Shiboken::TypeResolver::createObjectTypeResolver<QResizeEvent >("QResizeEvent*");
    Shiboken::TypeResolver::createObjectTypeResolver<QResizeEvent >(typeid(QResizeEvent).name());
}


} // extern "C"

