/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qstyleoptiontabv3_wrapper.h"

// Extra includes
#include <qstyleoption.h>
#include <qwidget.h>

using namespace Shiboken;

static int
SbkQStyleOptionTabV3_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    QStyleOptionTabV3* cptr = 0;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    if (!PyArg_UnpackTuple(args, "QStyleOptionTabV3", 0, 1, &(pyargs[0])))
        return -1;

    if (numArgs == 0) {
        // QStyleOptionTabV3()
        cptr = new QStyleOptionTabV3();
        //CppGenerator::writeParentChildManagement
    } else if (numArgs == 1 && PyNumber_Check(pyargs[0])) {
        int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
        // QStyleOptionTabV3(int)
        cptr = new QStyleOptionTabV3(cpp_arg0);
        //CppGenerator::writeParentChildManagement
    } else if (numArgs == 1 && Shiboken::Converter<QStyleOptionTab & >::isConvertible(pyargs[0])) {
        if (Shiboken::cppObjectIsInvalid(pyargs[0]))
            return -1;
        QStyleOptionTab* cpp_arg0 = Shiboken::Converter<QStyleOptionTab* >::toCpp(pyargs[0]);
        // QStyleOptionTabV3(QStyleOptionTab)
        cptr = new QStyleOptionTabV3(*cpp_arg0);
        //CppGenerator::writeParentChildManagement
    } else if (numArgs == 1 && Shiboken::Converter<QStyleOptionTabV2 & >::isConvertible(pyargs[0])) {
        if (Shiboken::cppObjectIsInvalid(pyargs[0]))
            return -1;
        std::auto_ptr<QStyleOptionTabV2 > cpp_arg0_auto_ptr;
        QStyleOptionTabV2* cpp_arg0 = Shiboken::Converter<QStyleOptionTabV2* >::toCpp(pyargs[0]);
        if (!SbkQStyleOptionTabV2_Check(pyargs[0]))
            cpp_arg0_auto_ptr = std::auto_ptr<QStyleOptionTabV2 >(cpp_arg0);
        // QStyleOptionTabV3(QStyleOptionTabV2)
        cptr = new QStyleOptionTabV3(*cpp_arg0);
        //CppGenerator::writeParentChildManagement
    } else if (numArgs == 1 && Shiboken::Converter<QStyleOptionTabV3 & >::isConvertible(pyargs[0])) {
        if (Shiboken::cppObjectIsInvalid(pyargs[0]))
            return -1;
        std::auto_ptr<QStyleOptionTabV3 > cpp_arg0_auto_ptr;
        QStyleOptionTabV3* cpp_arg0 = Shiboken::Converter<QStyleOptionTabV3* >::toCpp(pyargs[0]);
        if (!SbkQStyleOptionTabV3_Check(pyargs[0]))
            cpp_arg0_auto_ptr = std::auto_ptr<QStyleOptionTabV3 >(cpp_arg0);
        // QStyleOptionTabV3(QStyleOptionTabV3)
        cptr = new QStyleOptionTabV3(*cpp_arg0);
        //CppGenerator::writeParentChildManagement
    } else goto SbkQStyleOptionTabV3_Init_TypeError;

    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QStyleOptionTabV3 >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQStyleOptionTabV3_Init_TypeError;

    sbkSelf->validCppObject = 1;
    sbkSelf->referredObjects = new Shiboken::RefCountMap;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);

    return 1;

    SbkQStyleOptionTabV3_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtGui.QStyleOptionTab", "PySide.QtGui.QStyleOptionTabV2", "PySide.QtGui.QStyleOptionTabV3", "int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QStyleOptionTabV3", overloads);
        return -1;
}

static PyMethodDef SbkQStyleOptionTabV3_methods[] = {
    {0} // Sentinel
};

static PyObject* SbkQStyleOptionTabV3_get_documentMode(SbkBaseWrapper* self)
{
    return Shiboken::Converter<bool >::toPython(Shiboken::Converter<QStyleOptionTabV3* >::toCpp((PyObject*)self)->documentMode);
}
static int SbkQStyleOptionTabV3_set_documentMode(SbkBaseWrapper* self, PyObject* value)
{
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'documentMode' may not be deleted");
        return -1;
    }
    if (!PyNumber_Check(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'documentMode', 'bool' or convertible type expected");
        return -1;
    }

    Shiboken::Converter<QStyleOptionTabV3* >::toCpp((PyObject*)self)->documentMode = Shiboken::Converter<bool >::toCpp(value);

    return 0;
}

static PyObject* SbkQStyleOptionTabV3_get_rightButtonSize(SbkBaseWrapper* self)
{
    return Shiboken::Converter<QSize >::toPython(Shiboken::Converter<QStyleOptionTabV3* >::toCpp((PyObject*)self)->rightButtonSize);
}
static int SbkQStyleOptionTabV3_set_rightButtonSize(SbkBaseWrapper* self, PyObject* value)
{
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'rightButtonSize' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter<QSize >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'rightButtonSize', 'QSize' or convertible type expected");
        return -1;
    }

    Shiboken::Converter<QStyleOptionTabV3* >::toCpp((PyObject*)self)->rightButtonSize = Shiboken::Converter<QSize >::toCpp(value);

    return 0;
}

static PyObject* SbkQStyleOptionTabV3_get_leftButtonSize(SbkBaseWrapper* self)
{
    return Shiboken::Converter<QSize >::toPython(Shiboken::Converter<QStyleOptionTabV3* >::toCpp((PyObject*)self)->leftButtonSize);
}
static int SbkQStyleOptionTabV3_set_leftButtonSize(SbkBaseWrapper* self, PyObject* value)
{
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'leftButtonSize' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter<QSize >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'leftButtonSize', 'QSize' or convertible type expected");
        return -1;
    }

    Shiboken::Converter<QStyleOptionTabV3* >::toCpp((PyObject*)self)->leftButtonSize = Shiboken::Converter<QSize >::toCpp(value);

    return 0;
}

// Getters and Setters for QStyleOptionTabV3
static PyGetSetDef SbkQStyleOptionTabV3_getsetlist[] = {
    {const_cast<char*>("documentMode"), (getter)SbkQStyleOptionTabV3_get_documentMode, (setter)SbkQStyleOptionTabV3_set_documentMode},
    {const_cast<char*>("rightButtonSize"), (getter)SbkQStyleOptionTabV3_get_rightButtonSize, (setter)SbkQStyleOptionTabV3_set_rightButtonSize},
    {const_cast<char*>("leftButtonSize"), (getter)SbkQStyleOptionTabV3_get_leftButtonSize, (setter)SbkQStyleOptionTabV3_set_leftButtonSize},
    {0}  // Sentinel
};

extern "C"
{

// Class Definition -----------------------------------------------
static SbkBaseWrapperType SbkQStyleOptionTabV3_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QStyleOptionTabV3",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQStyleOptionTabV3_methods,
    /*tp_members*/          0,
    /*tp_getset*/           SbkQStyleOptionTabV3_getsetlist,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQStyleOptionTabV3_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QStyleOptionTabV3 >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0
};

static PyGetSetDef SbkPySide_QtGui_QStyleOptionTabV3_StyleOptionVersion_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtGui_QStyleOptionTabV3_StyleOptionVersion_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtGui_QStyleOptionTabV3_StyleOptionVersion_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "StyleOptionVersion",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtGui_QStyleOptionTabV3_StyleOptionVersion_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtGui_QStyleOptionTabV3_StyleOptionVersion_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtGui_QStyleOptionTabV3_StyleOptionVersion_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}


PyAPI_FUNC(void) init_QStyleOptionTabV3(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONTABV3_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQStyleOptionTabV3_Type);

    SbkQStyleOptionTabV3_Type.super.ht_type.tp_base = SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONTABV2_IDX];
    if (PyType_Ready((PyTypeObject*)&SbkQStyleOptionTabV3_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQStyleOptionTabV3_Type));
    PyModule_AddObject(module, "QStyleOptionTabV3",
        ((PyObject*)&SbkQStyleOptionTabV3_Type));

    // Initialize enums
    PyObject* enum_item;

    // init enum class: StyleOptionVersion
    SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONTABV3_STYLEOPTIONVERSION_IDX] = &SbkPySide_QtGui_QStyleOptionTabV3_StyleOptionVersion_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QStyleOptionTabV3_StyleOptionVersion_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtGui_QStyleOptionTabV3_StyleOptionVersion_Type);
    PyDict_SetItemString(SbkQStyleOptionTabV3_Type.super.ht_type.tp_dict,
            "StyleOptionVersion",((PyObject*)&SbkPySide_QtGui_QStyleOptionTabV3_StyleOptionVersion_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QStyleOptionTabV3_StyleOptionVersion_Type,
        (long) QStyleOptionTabV3::Version, "Version");
    PyDict_SetItemString(SbkQStyleOptionTabV3_Type.super.ht_type.tp_dict,
        "Version", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QStyleOptionTabV3_StyleOptionVersion_Type.tp_dict,
        "Version", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QStyleOptionTabV3::StyleOptionVersion");

    Shiboken::TypeResolver::createValueTypeResolver<QStyleOptionTabV3 >("QStyleOptionTabV3");
    Shiboken::TypeResolver::createValueTypeResolver<QStyleOptionTabV3 >(typeid(QStyleOptionTabV3).name());
}


} // extern "C"

