/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtxml_python.h"

#include "qdomdocumenttype_wrapper.h"

// Extra includes
#include <qdom.h>
#include <qstring.h>
#include <qtextstream.h>

using namespace Shiboken;

static int
SbkQDomDocumentType_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    QDomDocumentType* cptr = 0;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    if (!PyArg_UnpackTuple(args, "QDomDocumentType", 0, 1, &(pyargs[0])))
        return -1;

    if (numArgs == 0) {
        // QDomDocumentType()
        cptr = new QDomDocumentType();
        //CppGenerator::writeParentChildManagement
    } else if (numArgs == 1 && Shiboken::Converter<QDomDocumentType & >::isConvertible(pyargs[0])) {
        if (Shiboken::cppObjectIsInvalid(pyargs[0]))
            return -1;
        QDomDocumentType* cpp_arg0 = Shiboken::Converter<QDomDocumentType* >::toCpp(pyargs[0]);
        // QDomDocumentType(QDomDocumentType)
        cptr = new QDomDocumentType(*cpp_arg0);
        //CppGenerator::writeParentChildManagement
    } else goto SbkQDomDocumentType_Init_TypeError;

    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QDomDocumentType >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQDomDocumentType_Init_TypeError;

    sbkSelf->validCppObject = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);

    return 1;

    SbkQDomDocumentType_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtXml.QDomDocumentType", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtXml.QDomDocumentType", overloads);
        return -1;
}

static PyObject* SbkQDomDocumentTypeFunc_entities(PyObject* self)
{
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;

    PyObject* py_result = 0;

    // entities()const
    QDomDocumentType* cppSelf = Shiboken::Converter<QDomDocumentType* >::toCpp((PyObject*)self);
    QDomNamedNodeMap cpp_result = cppSelf->QDomDocumentType::entities();
    py_result = Shiboken::Converter<QDomNamedNodeMap >::toPython(cpp_result);
    //CppGenerator::writeParentChildManagement

    if (PyErr_Occurred() || !py_result) {
        Py_XDECREF(py_result);
        return 0;
    }
    return py_result;
}

static PyObject* SbkQDomDocumentTypeFunc_internalSubset(PyObject* self)
{
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;

    PyObject* py_result = 0;

    // internalSubset()const
    QDomDocumentType* cppSelf = Shiboken::Converter<QDomDocumentType* >::toCpp((PyObject*)self);
    QString cpp_result = cppSelf->QDomDocumentType::internalSubset();
    py_result = Shiboken::Converter<QString >::toPython(cpp_result);
    //CppGenerator::writeParentChildManagement

    if (PyErr_Occurred() || !py_result) {
        Py_XDECREF(py_result);
        return 0;
    }
    return py_result;
}

static PyObject* SbkQDomDocumentTypeFunc_name(PyObject* self)
{
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;

    PyObject* py_result = 0;

    // name()const
    QDomDocumentType* cppSelf = Shiboken::Converter<QDomDocumentType* >::toCpp((PyObject*)self);
    QString cpp_result = cppSelf->QDomDocumentType::name();
    py_result = Shiboken::Converter<QString >::toPython(cpp_result);
    //CppGenerator::writeParentChildManagement

    if (PyErr_Occurred() || !py_result) {
        Py_XDECREF(py_result);
        return 0;
    }
    return py_result;
}

static PyObject* SbkQDomDocumentTypeFunc_notations(PyObject* self)
{
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;

    PyObject* py_result = 0;

    // notations()const
    QDomDocumentType* cppSelf = Shiboken::Converter<QDomDocumentType* >::toCpp((PyObject*)self);
    QDomNamedNodeMap cpp_result = cppSelf->QDomDocumentType::notations();
    py_result = Shiboken::Converter<QDomNamedNodeMap >::toPython(cpp_result);
    //CppGenerator::writeParentChildManagement

    if (PyErr_Occurred() || !py_result) {
        Py_XDECREF(py_result);
        return 0;
    }
    return py_result;
}

static PyObject* SbkQDomDocumentTypeFunc_publicId(PyObject* self)
{
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;

    PyObject* py_result = 0;

    // publicId()const
    QDomDocumentType* cppSelf = Shiboken::Converter<QDomDocumentType* >::toCpp((PyObject*)self);
    QString cpp_result = cppSelf->QDomDocumentType::publicId();
    py_result = Shiboken::Converter<QString >::toPython(cpp_result);
    //CppGenerator::writeParentChildManagement

    if (PyErr_Occurred() || !py_result) {
        Py_XDECREF(py_result);
        return 0;
    }
    return py_result;
}

static PyObject* SbkQDomDocumentTypeFunc_systemId(PyObject* self)
{
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;

    PyObject* py_result = 0;

    // systemId()const
    QDomDocumentType* cppSelf = Shiboken::Converter<QDomDocumentType* >::toCpp((PyObject*)self);
    QString cpp_result = cppSelf->QDomDocumentType::systemId();
    py_result = Shiboken::Converter<QString >::toPython(cpp_result);
    //CppGenerator::writeParentChildManagement

    if (PyErr_Occurred() || !py_result) {
        Py_XDECREF(py_result);
        return 0;
    }
    return py_result;
}

static PyMethodDef SbkQDomDocumentType_methods[] = {
    {"entities", (PyCFunction)SbkQDomDocumentTypeFunc_entities, METH_NOARGS},
    {"internalSubset", (PyCFunction)SbkQDomDocumentTypeFunc_internalSubset, METH_NOARGS},
    {"name", (PyCFunction)SbkQDomDocumentTypeFunc_name, METH_NOARGS},
    {"notations", (PyCFunction)SbkQDomDocumentTypeFunc_notations, METH_NOARGS},
    {"publicId", (PyCFunction)SbkQDomDocumentTypeFunc_publicId, METH_NOARGS},
    {"systemId", (PyCFunction)SbkQDomDocumentTypeFunc_systemId, METH_NOARGS},
    {0} // Sentinel
};

extern "C"
{

// Class Definition -----------------------------------------------
static SbkBaseWrapperType SbkQDomDocumentType_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtXml.QDomDocumentType",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQDomDocumentType_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQDomDocumentType_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QDomDocumentType >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0
};


PyAPI_FUNC(void) init_QDomDocumentType(PyObject* module)
{
    SbkPySide_QtXmlTypes[SBK_QDOMDOCUMENTTYPE_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQDomDocumentType_Type);

    SbkQDomDocumentType_Type.super.ht_type.tp_base = SbkPySide_QtXmlTypes[SBK_QDOMNODE_IDX];
    if (PyType_Ready((PyTypeObject*)&SbkQDomDocumentType_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQDomDocumentType_Type));
    PyModule_AddObject(module, "QDomDocumentType",
        ((PyObject*)&SbkQDomDocumentType_Type));

    Shiboken::TypeResolver::createValueTypeResolver<QDomDocumentType >("QDomDocumentType");
    Shiboken::TypeResolver::createValueTypeResolver<QDomDocumentType >(typeid(QDomDocumentType).name());
}


} // extern "C"

