/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtxml_python.h"

#include "qdomprocessinginstruction_wrapper.h"

// Extra includes
#include <qdom.h>
#include <qstring.h>
#include <qtextstream.h>

using namespace Shiboken;

static int
SbkQDomProcessingInstruction_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    QDomProcessingInstruction* cptr = 0;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    if (!PyArg_UnpackTuple(args, "QDomProcessingInstruction", 0, 1, &(pyargs[0])))
        return -1;

    if (numArgs == 0) {
        // QDomProcessingInstruction()
        cptr = new QDomProcessingInstruction();
        //CppGenerator::writeParentChildManagement
    } else if (numArgs == 1 && Shiboken::Converter<QDomProcessingInstruction & >::isConvertible(pyargs[0])) {
        if (Shiboken::cppObjectIsInvalid(pyargs[0]))
            return -1;
        QDomProcessingInstruction* cpp_arg0 = Shiboken::Converter<QDomProcessingInstruction* >::toCpp(pyargs[0]);
        // QDomProcessingInstruction(QDomProcessingInstruction)
        cptr = new QDomProcessingInstruction(*cpp_arg0);
        //CppGenerator::writeParentChildManagement
    } else goto SbkQDomProcessingInstruction_Init_TypeError;

    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QDomProcessingInstruction >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQDomProcessingInstruction_Init_TypeError;

    sbkSelf->validCppObject = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);

    return 1;

    SbkQDomProcessingInstruction_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtXml.QDomProcessingInstruction", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtXml.QDomProcessingInstruction", overloads);
        return -1;
}

static PyObject* SbkQDomProcessingInstructionFunc_data(PyObject* self)
{
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;

    PyObject* py_result = 0;

    // data()const
    QDomProcessingInstruction* cppSelf = Shiboken::Converter<QDomProcessingInstruction* >::toCpp((PyObject*)self);
    QString cpp_result = cppSelf->QDomProcessingInstruction::data();
    py_result = Shiboken::Converter<QString >::toPython(cpp_result);
    //CppGenerator::writeParentChildManagement

    if (PyErr_Occurred() || !py_result) {
        Py_XDECREF(py_result);
        return 0;
    }
    return py_result;
}

static PyObject* SbkQDomProcessingInstructionFunc_setData(PyObject* self, PyObject* arg)
{
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;


    if (Shiboken::Converter<QString & >::isConvertible(arg)) {
        if (Shiboken::cppObjectIsInvalid(arg))
            return 0;
        std::auto_ptr<QString > cpp_arg0_auto_ptr;
        QString* cpp_arg0 = Shiboken::Converter<QString* >::toCpp(arg);
        if (!SbkQString_Check(arg))
            cpp_arg0_auto_ptr = std::auto_ptr<QString >(cpp_arg0);
        // setData(QString)
        QDomProcessingInstruction* cppSelf = Shiboken::Converter<QDomProcessingInstruction* >::toCpp((PyObject*)self);
        cppSelf->QDomProcessingInstruction::setData(*cpp_arg0);
        //CppGenerator::writeParentChildManagement
    } else goto SbkQDomProcessingInstructionFunc_setData_TypeError;

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQDomProcessingInstructionFunc_setData_TypeError:
        const char* overloads[] = {"PySide.QtCore.QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXml.QDomProcessingInstruction.setData", overloads);
        return 0;
}

static PyObject* SbkQDomProcessingInstructionFunc_target(PyObject* self)
{
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;

    PyObject* py_result = 0;

    // target()const
    QDomProcessingInstruction* cppSelf = Shiboken::Converter<QDomProcessingInstruction* >::toCpp((PyObject*)self);
    QString cpp_result = cppSelf->QDomProcessingInstruction::target();
    py_result = Shiboken::Converter<QString >::toPython(cpp_result);
    //CppGenerator::writeParentChildManagement

    if (PyErr_Occurred() || !py_result) {
        Py_XDECREF(py_result);
        return 0;
    }
    return py_result;
}

static PyMethodDef SbkQDomProcessingInstruction_methods[] = {
    {"data", (PyCFunction)SbkQDomProcessingInstructionFunc_data, METH_NOARGS},
    {"setData", (PyCFunction)SbkQDomProcessingInstructionFunc_setData, METH_O},
    {"target", (PyCFunction)SbkQDomProcessingInstructionFunc_target, METH_NOARGS},
    {0} // Sentinel
};

extern "C"
{

// Class Definition -----------------------------------------------
static SbkBaseWrapperType SbkQDomProcessingInstruction_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtXml.QDomProcessingInstruction",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQDomProcessingInstruction_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQDomProcessingInstruction_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QDomProcessingInstruction >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0
};


PyAPI_FUNC(void) init_QDomProcessingInstruction(PyObject* module)
{
    SbkPySide_QtXmlTypes[SBK_QDOMPROCESSINGINSTRUCTION_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQDomProcessingInstruction_Type);

    SbkQDomProcessingInstruction_Type.super.ht_type.tp_base = SbkPySide_QtXmlTypes[SBK_QDOMNODE_IDX];
    if (PyType_Ready((PyTypeObject*)&SbkQDomProcessingInstruction_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQDomProcessingInstruction_Type));
    PyModule_AddObject(module, "QDomProcessingInstruction",
        ((PyObject*)&SbkQDomProcessingInstruction_Type));

    Shiboken::TypeResolver::createValueTypeResolver<QDomProcessingInstruction >("QDomProcessingInstruction");
    Shiboken::TypeResolver::createValueTypeResolver<QDomProcessingInstruction >(typeid(QDomProcessingInstruction).name());
}


} // extern "C"

