/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtxmlpatterns_python.h"

#include "qsourcelocation_wrapper.h"

// Extra includes
#include <qsourcelocation.h>
#include <qurl.h>

using namespace Shiboken;

static int
SbkQSourceLocation_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    QSourceLocation* cptr = 0;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    if (!PyArg_UnpackTuple(args, "QSourceLocation", 0, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return -1;

    if (numArgs == 0) {
        // QSourceLocation()
        cptr = new QSourceLocation();
        //CppGenerator::writeParentChildManagement
    } else if (Shiboken::Converter<QUrl & >::isConvertible(pyargs[0])) {
        if (Shiboken::cppObjectIsInvalid(pyargs[0]))
            return -1;
        std::auto_ptr<QUrl > cpp_arg0_auto_ptr;
        QUrl* cpp_arg0 = Shiboken::Converter<QUrl* >::toCpp(pyargs[0]);
        if (!SbkQUrl_Check(pyargs[0]))
            cpp_arg0_auto_ptr = std::auto_ptr<QUrl >(cpp_arg0);
        if (numArgs == 1) {
            // QSourceLocation(QUrl,int,int)
            cptr = new QSourceLocation(*cpp_arg0);
            //CppGenerator::writeParentChildManagement
        } else if (PyNumber_Check(pyargs[1])) {
            int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
            if (numArgs == 2) {
                // QSourceLocation(QUrl,int,int)
                cptr = new QSourceLocation(*cpp_arg0, cpp_arg1);
                //CppGenerator::writeParentChildManagement
            } else if (PyNumber_Check(pyargs[2])) {
                int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
                // QSourceLocation(QUrl,int,int)
                cptr = new QSourceLocation(*cpp_arg0, cpp_arg1, cpp_arg2);
                //CppGenerator::writeParentChildManagement
            } else goto SbkQSourceLocation_Init_TypeError;
        } else goto SbkQSourceLocation_Init_TypeError;
    } else if (numArgs == 1 && Shiboken::Converter<QSourceLocation & >::isConvertible(pyargs[0])) {
        if (Shiboken::cppObjectIsInvalid(pyargs[0]))
            return -1;
        std::auto_ptr<QSourceLocation > cpp_arg0_auto_ptr;
        QSourceLocation* cpp_arg0 = Shiboken::Converter<QSourceLocation* >::toCpp(pyargs[0]);
        if (!SbkQSourceLocation_Check(pyargs[0]))
            cpp_arg0_auto_ptr = std::auto_ptr<QSourceLocation >(cpp_arg0);
        // QSourceLocation(QSourceLocation)
        cptr = new QSourceLocation(*cpp_arg0);
        //CppGenerator::writeParentChildManagement
    } else goto SbkQSourceLocation_Init_TypeError;

    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QSourceLocation >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQSourceLocation_Init_TypeError;

    sbkSelf->validCppObject = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);

    return 1;

    SbkQSourceLocation_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtXmlPatterns.QSourceLocation", "PySide.QtCore.QUrl, int = -1, int = -1", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtXmlPatterns.QSourceLocation", overloads);
        return -1;
}

static PyObject* SbkQSourceLocationFunc_column(PyObject* self)
{
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;

    PyObject* py_result = 0;

    // column()const
    QSourceLocation* cppSelf = Shiboken::Converter<QSourceLocation* >::toCpp((PyObject*)self);
    qint64 cpp_result = cppSelf->QSourceLocation::column();
    py_result = Shiboken::Converter<long long >::toPython(cpp_result);
    //CppGenerator::writeParentChildManagement

    if (PyErr_Occurred() || !py_result) {
        Py_XDECREF(py_result);
        return 0;
    }
    return py_result;
}

static PyObject* SbkQSourceLocationFunc_isNull(PyObject* self)
{
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;

    PyObject* py_result = 0;

    // isNull()const
    QSourceLocation* cppSelf = Shiboken::Converter<QSourceLocation* >::toCpp((PyObject*)self);
    bool cpp_result = cppSelf->QSourceLocation::isNull();
    py_result = Shiboken::Converter<bool >::toPython(cpp_result);
    //CppGenerator::writeParentChildManagement

    if (PyErr_Occurred() || !py_result) {
        Py_XDECREF(py_result);
        return 0;
    }
    return py_result;
}

static PyObject* SbkQSourceLocationFunc_line(PyObject* self)
{
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;

    PyObject* py_result = 0;

    // line()const
    QSourceLocation* cppSelf = Shiboken::Converter<QSourceLocation* >::toCpp((PyObject*)self);
    qint64 cpp_result = cppSelf->QSourceLocation::line();
    py_result = Shiboken::Converter<long long >::toPython(cpp_result);
    //CppGenerator::writeParentChildManagement

    if (PyErr_Occurred() || !py_result) {
        Py_XDECREF(py_result);
        return 0;
    }
    return py_result;
}

static PyObject* SbkQSourceLocationFunc_setColumn(PyObject* self, PyObject* arg)
{
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;


    if (PyNumber_Check(arg)) {
        qint64 cpp_arg0 = Shiboken::Converter<qint64 >::toCpp(arg);
        // setColumn(qint64)
        QSourceLocation* cppSelf = Shiboken::Converter<QSourceLocation* >::toCpp((PyObject*)self);
        cppSelf->QSourceLocation::setColumn(cpp_arg0);
        //CppGenerator::writeParentChildManagement
    } else goto SbkQSourceLocationFunc_setColumn_TypeError;

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQSourceLocationFunc_setColumn_TypeError:
        const char* overloads[] = {"long long", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXmlPatterns.QSourceLocation.setColumn", overloads);
        return 0;
}

static PyObject* SbkQSourceLocationFunc_setLine(PyObject* self, PyObject* arg)
{
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;


    if (PyNumber_Check(arg)) {
        qint64 cpp_arg0 = Shiboken::Converter<qint64 >::toCpp(arg);
        // setLine(qint64)
        QSourceLocation* cppSelf = Shiboken::Converter<QSourceLocation* >::toCpp((PyObject*)self);
        cppSelf->QSourceLocation::setLine(cpp_arg0);
        //CppGenerator::writeParentChildManagement
    } else goto SbkQSourceLocationFunc_setLine_TypeError;

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQSourceLocationFunc_setLine_TypeError:
        const char* overloads[] = {"long long", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXmlPatterns.QSourceLocation.setLine", overloads);
        return 0;
}

static PyObject* SbkQSourceLocationFunc_setUri(PyObject* self, PyObject* arg)
{
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;


    if (Shiboken::Converter<QUrl & >::isConvertible(arg)) {
        if (Shiboken::cppObjectIsInvalid(arg))
            return 0;
        std::auto_ptr<QUrl > cpp_arg0_auto_ptr;
        QUrl* cpp_arg0 = Shiboken::Converter<QUrl* >::toCpp(arg);
        if (!SbkQUrl_Check(arg))
            cpp_arg0_auto_ptr = std::auto_ptr<QUrl >(cpp_arg0);
        // setUri(QUrl)
        QSourceLocation* cppSelf = Shiboken::Converter<QSourceLocation* >::toCpp((PyObject*)self);
        cppSelf->QSourceLocation::setUri(*cpp_arg0);
        //CppGenerator::writeParentChildManagement
    } else goto SbkQSourceLocationFunc_setUri_TypeError;

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQSourceLocationFunc_setUri_TypeError:
        const char* overloads[] = {"PySide.QtCore.QUrl", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXmlPatterns.QSourceLocation.setUri", overloads);
        return 0;
}

static PyObject* SbkQSourceLocationFunc_uri(PyObject* self)
{
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;

    PyObject* py_result = 0;

    // uri()const
    QSourceLocation* cppSelf = Shiboken::Converter<QSourceLocation* >::toCpp((PyObject*)self);
    QUrl cpp_result = cppSelf->QSourceLocation::uri();
    py_result = Shiboken::Converter<QUrl >::toPython(cpp_result);
    //CppGenerator::writeParentChildManagement

    if (PyErr_Occurred() || !py_result) {
        Py_XDECREF(py_result);
        return 0;
    }
    return py_result;
}

static PyMethodDef SbkQSourceLocation_methods[] = {
    {"column", (PyCFunction)SbkQSourceLocationFunc_column, METH_NOARGS},
    {"isNull", (PyCFunction)SbkQSourceLocationFunc_isNull, METH_NOARGS},
    {"line", (PyCFunction)SbkQSourceLocationFunc_line, METH_NOARGS},
    {"setColumn", (PyCFunction)SbkQSourceLocationFunc_setColumn, METH_O},
    {"setLine", (PyCFunction)SbkQSourceLocationFunc_setLine, METH_O},
    {"setUri", (PyCFunction)SbkQSourceLocationFunc_setUri, METH_O},
    {"uri", (PyCFunction)SbkQSourceLocationFunc_uri, METH_NOARGS},
    {0} // Sentinel
};

// Rich comparison
static PyObject* SbkQSourceLocation_richcompare(PyObject* self, PyObject* other, int op)
{
    bool result = false;
    QSourceLocation& cpp_self = *Shiboken::Converter<QSourceLocation* >::toCpp((PyObject*)self);

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter<QSourceLocation & >::isConvertible(other)) {
                // operator!=(const QSourceLocation & other) const
                QSourceLocation* cpp_other = Shiboken::Converter<QSourceLocation* >::toCpp((PyObject*)other);
                result = !cpp_other ? cpp_self == Shiboken::Converter<QSourceLocation  >::toCpp(other) : (cpp_self != (*cpp_other));
            } else if (Shiboken::Converter<QSourceLocation >::isConvertible(other)) {
                if (Shiboken::cppObjectIsInvalid(other))
                    return 0;
                std::auto_ptr<QSourceLocation > cpp_other_auto_ptr;
                QSourceLocation* cpp_other = Shiboken::Converter<QSourceLocation* >::toCpp(other);
                if (!SbkQSourceLocation_Check(other))
                    cpp_other_auto_ptr = std::auto_ptr<QSourceLocation >(cpp_other);
                result = (cpp_self != (*cpp_other));
            } else goto SbkQSourceLocation_RichComparison_TypeError;

            break;
        case Py_EQ:
            if (Shiboken::Converter<QSourceLocation & >::isConvertible(other)) {
                // operator==(const QSourceLocation & other) const
                QSourceLocation* cpp_other = Shiboken::Converter<QSourceLocation* >::toCpp((PyObject*)other);
                result = !cpp_other ? cpp_self == Shiboken::Converter<QSourceLocation  >::toCpp(other) : (cpp_self == (*cpp_other));
            } else if (Shiboken::Converter<QSourceLocation >::isConvertible(other)) {
                if (Shiboken::cppObjectIsInvalid(other))
                    return 0;
                std::auto_ptr<QSourceLocation > cpp_other_auto_ptr;
                QSourceLocation* cpp_other = Shiboken::Converter<QSourceLocation* >::toCpp(other);
                if (!SbkQSourceLocation_Check(other))
                    cpp_other_auto_ptr = std::auto_ptr<QSourceLocation >(cpp_other);
                result = (cpp_self == (*cpp_other));
            } else goto SbkQSourceLocation_RichComparison_TypeError;

            break;
        default:
            PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
            return 0;
    }

    if (result)
        Py_RETURN_TRUE;
    SbkQSourceLocation_RichComparison_TypeError:
    Py_RETURN_FALSE;

}

extern "C"
{

// Class Definition -----------------------------------------------
static SbkBaseWrapperType SbkQSourceLocation_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtXmlPatterns.QSourceLocation",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      SbkQSourceLocation_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQSourceLocation_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQSourceLocation_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QSourceLocation >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0
};


PyAPI_FUNC(void) init_QSourceLocation(PyObject* module)
{
    SbkPySide_QtXmlPatternsTypes[SBK_QSOURCELOCATION_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQSourceLocation_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQSourceLocation_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQSourceLocation_Type));
    PyModule_AddObject(module, "QSourceLocation",
        ((PyObject*)&SbkQSourceLocation_Type));

    Shiboken::TypeResolver::createValueTypeResolver<QSourceLocation >("QSourceLocation");
    Shiboken::TypeResolver::createValueTypeResolver<QSourceLocation >(typeid(QSourceLocation).name());
}


} // extern "C"

